@@ -255,9 +255,14 @@ oobs_nfs_config_commit (OobsObject *object)
 OobsObject*
 oobs_nfs_config_get (void)
 {
-  return g_object_new (OOBS_TYPE_NFS_CONFIG,
-		       "remote-object", NFS_CONFIG_REMOTE_OBJECT,
-		       NULL);
+  static OobsObject *the_object = NULL;
+
+  if (!the_object)
+    the_object = g_object_new (OOBS_TYPE_NFS_CONFIG,
+                               "remote-object", NFS_CONFIG_REMOTE_OBJECT,
+                               NULL);
+
+  return the_object;
 }
 
 /**
